# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImagerService.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ImagerService.proto',
  package='endpoints.imager',
  syntax='proto3',
  serialized_options=b'\n\034com.kekflow.endpoints.imagerB\022ImagerServiceProtoP\001',
  serialized_pb=b'\n\x13ImagerService.proto\x12\x10\x65ndpoints.imager\"$\n\x14\x44ownloadImageRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\"\'\n\tDataChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04size\x18\x02 \x01(\x05\x32\x64\n\rImagerService\x12S\n\x08getImage\x12&.endpoints.imager.DownloadImageRequest\x1a\x1b.endpoints.imager.DataChunk\"\x00\x30\x01\x42\x34\n\x1c\x63om.kekflow.endpoints.imagerB\x12ImagerServiceProtoP\x01\x62\x06proto3'
)




_DOWNLOADIMAGEREQUEST = _descriptor.Descriptor(
  name='DownloadImageRequest',
  full_name='endpoints.imager.DownloadImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='endpoints.imager.DownloadImageRequest.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=77,
)


_DATACHUNK = _descriptor.Descriptor(
  name='DataChunk',
  full_name='endpoints.imager.DataChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='endpoints.imager.DataChunk.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='endpoints.imager.DataChunk.size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=118,
)

DESCRIPTOR.message_types_by_name['DownloadImageRequest'] = _DOWNLOADIMAGEREQUEST
DESCRIPTOR.message_types_by_name['DataChunk'] = _DATACHUNK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DownloadImageRequest = _reflection.GeneratedProtocolMessageType('DownloadImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADIMAGEREQUEST,
  '__module__' : 'ImagerService_pb2'
  # @@protoc_insertion_point(class_scope:endpoints.imager.DownloadImageRequest)
  })
_sym_db.RegisterMessage(DownloadImageRequest)

DataChunk = _reflection.GeneratedProtocolMessageType('DataChunk', (_message.Message,), {
  'DESCRIPTOR' : _DATACHUNK,
  '__module__' : 'ImagerService_pb2'
  # @@protoc_insertion_point(class_scope:endpoints.imager.DataChunk)
  })
_sym_db.RegisterMessage(DataChunk)


DESCRIPTOR._options = None

_IMAGERSERVICE = _descriptor.ServiceDescriptor(
  name='ImagerService',
  full_name='endpoints.imager.ImagerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=120,
  serialized_end=220,
  methods=[
  _descriptor.MethodDescriptor(
    name='getImage',
    full_name='endpoints.imager.ImagerService.getImage',
    index=0,
    containing_service=None,
    input_type=_DOWNLOADIMAGEREQUEST,
    output_type=_DATACHUNK,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_IMAGERSERVICE)

DESCRIPTOR.services_by_name['ImagerService'] = _IMAGERSERVICE

# @@protoc_insertion_point(module_scope)
