# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import ImagerService_pb2 as ImagerService__pb2


class ImagerServiceStub(object):
    """Missing associated documentation comment in .proto file"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getImage = channel.unary_stream(
                '/endpoints.imager.ImagerService/getImage',
                request_serializer=ImagerService__pb2.DownloadImageRequest.SerializeToString,
                response_deserializer=ImagerService__pb2.DataChunk.FromString,
                )


class ImagerServiceServicer(object):
    """Missing associated documentation comment in .proto file"""

    def getImage(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getImage': grpc.unary_stream_rpc_method_handler(
                    servicer.getImage,
                    request_deserializer=ImagerService__pb2.DownloadImageRequest.FromString,
                    response_serializer=ImagerService__pb2.DataChunk.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'endpoints.imager.ImagerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImagerService(object):
    """Missing associated documentation comment in .proto file"""

    @staticmethod
    def getImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/endpoints.imager.ImagerService/getImage',
            ImagerService__pb2.DownloadImageRequest.SerializeToString,
            ImagerService__pb2.DataChunk.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)
